@@ -73,11 +73,8 @@ face_chooser_menu_get_property (GObject *object,
 static GtkhtmlFace *
 face_chooser_menu_get_current_face (GtkhtmlFaceChooser *chooser)
 {
-	GtkhtmlFaceChooserMenuPrivate *priv;
 	GtkWidget *item;
 
-	priv = GTKHTML_FACE_CHOOSER_MENU_GET_PRIVATE (chooser);
-
 	item = gtk_menu_get_active (GTK_MENU (chooser));
 	if (item == NULL)
 		return NULL;
@@ -89,11 +86,8 @@ static void
 face_chooser_menu_set_current_face (GtkhtmlFaceChooser *chooser,
                                     GtkhtmlFace *face)
 {
-	GtkhtmlFaceChooserMenuPrivate *priv;
 	GList *list, *iter;
 
-	priv = GTKHTML_FACE_CHOOSER_MENU_GET_PRIVATE (chooser);
-
 	list = gtk_container_get_children (GTK_CONTAINER (chooser));
 
 	for (iter = list; iter != NULL; iter = iter->next) {
