@@ -73,7 +73,7 @@ gtk_html_embedded_get_type (void)
 }
 
 static void
-free_param(void *key, void *value, void *data)
+free_param(gpointer key, gpointer value, gpointer data)
 {
 	g_free (key);
 	g_free (value);
@@ -103,7 +103,7 @@ static void gtk_html_embedded_add (GtkContainer *container, GtkWidget *child)
 	g_return_if_fail (container != NULL);
 
 	/* can't add something twice */
-	g_return_if_fail( GTK_BIN(container)->child == NULL );
+	g_return_if_fail (gtk_bin_get_child (GTK_BIN (container)) == NULL);
 
 	old_add(container, child);
 	gtk_html_embedded_changed(GTK_HTML_EMBEDDED(container));
@@ -112,7 +112,7 @@ static void gtk_html_embedded_add (GtkContainer *container, GtkWidget *child)
 static void gtk_html_embedded_remove (GtkContainer *container, GtkWidget *child)
 {
 	g_return_if_fail (container != NULL);
-	g_return_if_fail( GTK_BIN(container)->child != NULL );
+	g_return_if_fail (gtk_bin_get_child (GTK_BIN (container)) != NULL);
 
 	old_remove(container, child);
 
@@ -169,7 +169,7 @@ gtk_html_embedded_class_init (GtkHTMLEmbeddedClass *class)
 	widget_class = GTK_WIDGET_CLASS (class);
 	container_class = GTK_CONTAINER_CLASS (class);
 
-	parent_class = gtk_type_class (gtk_bin_get_type ());
+	parent_class = g_type_class_peek_parent (class);
 
 	signals [CHANGED] =
 		g_signal_new ("changed",
@@ -213,15 +213,15 @@ gtk_html_embedded_class_init (GtkHTMLEmbeddedClass *class)
 static void
 gtk_html_embedded_size_request (GtkWidget *widget, GtkRequisition *requisition)
 {
-	GtkBin *bin;
+	GtkWidget *child;
 
 	g_return_if_fail (widget != NULL);
 	g_return_if_fail (requisition != NULL);
 
-	bin = GTK_BIN (widget);
+	child = gtk_bin_get_child (GTK_BIN (widget));
 
-	if (bin->child) {
-		gtk_widget_size_request (bin->child, requisition);
+	if (child) {
+		gtk_widget_size_request (child, requisition);
 	} else {
 		requisition->width = widget->requisition.width;
 		requisition->height = widget->requisition.height;
@@ -231,15 +231,19 @@ gtk_html_embedded_size_request (GtkWidget *widget, GtkRequisition *requisition)
 static void
 gtk_html_embedded_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
-	GtkBin *bin;
+	GtkWidget *child;
 
 	g_return_if_fail (widget != NULL);
 	g_return_if_fail (allocation != NULL);
 
-	bin = GTK_BIN (widget);
+	child = gtk_bin_get_child (GTK_BIN (widget));
 
-	if (bin->child && GTK_WIDGET_VISIBLE (bin->child)) {
-		gtk_widget_size_allocate(bin->child, allocation);
+#if GTK_CHECK_VERSION(2,19,7)
+	if (child && gtk_widget_get_visible (child)) {
+#else
+	if (child && GTK_WIDGET_VISIBLE (child)) {
+#endif
+		gtk_widget_size_allocate (child, allocation);
 	}
 	widget->allocation = *allocation;
 }
@@ -260,7 +264,7 @@ gtk_html_embedded_init (GtkHTMLEmbedded *ge)
  * Return value: A new GtkHTMLEmbedded widget.
  **/
 GtkWidget *
-gtk_html_embedded_new (char *classid, char *name, char *type, char *data, int width, int height)
+gtk_html_embedded_new (gchar *classid, gchar *name, gchar *type, gchar *data, gint width, gint height)
 {
 	GtkHTMLEmbedded *em;
 
@@ -286,8 +290,8 @@ gtk_html_embedded_new (char *classid, char *name, char *type, char *data, int wi
  *
  * Returns: the value of the parameter.
  */
-char *
-gtk_html_embedded_get_parameter (GtkHTMLEmbedded *ge, char *param)
+gchar *
+gtk_html_embedded_get_parameter (GtkHTMLEmbedded *ge, gchar *param)
 {
 	return g_hash_table_lookup (ge->params, param);
 }
@@ -301,7 +305,7 @@ gtk_html_embedded_get_parameter (GtkHTMLEmbedded *ge, char *param)
  * The parameter named @name to the @value.
  */
 void
-gtk_html_embedded_set_parameter (GtkHTMLEmbedded *ge, char *param, char *value)
+gtk_html_embedded_set_parameter (GtkHTMLEmbedded *ge, gchar *param, gchar *value)
 {
 	gchar *lookup;
 
@@ -323,7 +327,7 @@ gtk_html_embedded_set_parameter (GtkHTMLEmbedded *ge, char *param, char *value)
  * Set the descent of the widget beneath the baseline.
  */
 void
-gtk_html_embedded_set_descent (GtkHTMLEmbedded *ge, int descent)
+gtk_html_embedded_set_descent (GtkHTMLEmbedded *ge, gint descent)
 {
 	if (ge->descent == descent)
 		return;
