@@ -51,7 +51,7 @@ typedef enum {
 	HTML_TABLE_CELL_HEADING,
 	HTML_TABLE_CELL_HALIGN,
 	HTML_TABLE_CELL_VALIGN,
-	HTML_TABLE_CELL_WIDTH,
+	HTML_TABLE_CELL_WIDTH
 } HTMLTableCellAttrType;
 
 union _HTMLTableCellUndoAttr {
